@@ -64,7 +64,7 @@ void YFrameWindow::updateMenu() {
         windowMenu->disableCommand(actionSize);
     if (!(func & ffMinimize))
         windowMenu->disableCommand(actionMinimize);
-#ifndef	CONFIG_PDA
+#ifndef CONFIG_PDA
     if (!(func & ffHide))
         windowMenu->disableCommand(actionHide);
 #endif
@@ -301,42 +301,23 @@ void YFrameWindow::layoutShape() {
 }
 
 void YFrameWindow::configure(const YRect &r, const bool resized) {
-    //int oldX = this->x();
-    //int oldY= this->y();
-
     MSG(("configure %d %d %d %d", r.x(), r.y(), r.width(), r.height()));
 
-#ifdef CONFIG_SHAPE
-///    int oldWidth = container()->width();
-///    int oldHeight = container()->height();
-///    int oldcx = container()->x();
-///    int oldcy = container()->y();
-#endif
-
     YWindow::configure(r, resized);
 
     layoutTitleBar();
     layoutButtons();
     layoutResizeIndicators();
     layoutClient();
-    if (resized) layoutShape();
+    if (resized) {
+        layoutShape();
+        if (affectsWorkArea())
+            manager->updateWorkArea();
+    }
 
 #warning "make a test program for this"
     ///if (x != oldX || y != oldY)
     sendConfigure();
-
-#ifdef CONFIG_SHAPE
-///    int cx = container()->x();
-///    int cy = container()->y();
-    if (resized)
-        ///oldWidth != container()->width() ||
-    	///oldHeight != container()->height() ||
-        ///cx != oldcx || cy != oldcy)
-///        setShape();
-#endif
-
-    if (affectsWorkArea())
-	manager->updateWorkArea();
 }
 
 void YFrameWindow::layoutTitleBar() {
@@ -377,16 +358,16 @@ YFrameButton *YFrameWindow::getButton(char c) {
 void YFrameWindow::positionButton(YFrameButton *b, int &xPos, bool onRight) {
     /// !!! clean this up
     if (b == fMenuButton) {
-	const unsigned bw((wmLook == lookPixmap || wmLook == lookMetal ||
-			   wmLook == lookGtk) &&
-			   showFrameIcon || b->getImage(0) == null ?
-			   titleY() : b->getImage(0)->width());
+        const unsigned bw((wmLook == lookPixmap || wmLook == lookMetal ||
+                           wmLook == lookGtk) &&
+                          showFrameIcon || b->getImage(0) == null ?
+                          titleY() : b->getImage(0)->width());
 
         if (onRight) xPos -= bw;
         b->setGeometry(YRect(xPos, 0, bw, titleY()));
         if (!onRight) xPos += bw;
     } else if (wmLook == lookPixmap || wmLook == lookMetal || wmLook == lookGtk) {
-	const unsigned bw(b->getImage(0) != null ? b->getImage(0)->width() : titleY());
+        const unsigned bw(b->getImage(0) != null ? b->getImage(0)->width() : titleY());
 
         if (onRight) xPos -= bw;
         b->setGeometry(YRect(xPos, 0, bw, titleY()));
@@ -451,7 +432,7 @@ void YFrameWindow::layoutButtons() {
             fDepthButton->hide();
 
 #ifdef CONFIG_LOOK_PIXMAP
-	const int pi(focused() ? 1 : 0);
+    const int pi(focused() ? 1 : 0);
 #endif
 
     if (titleButtonsLeft) {
@@ -482,7 +463,7 @@ void YFrameWindow::layoutButtons() {
     if (titleButtonsRight) {
 #ifdef CONFIG_LOOK_PIXMAP
         int xPos(width() - 2 * borderX() -
-		(titleQ[pi] != null ? titleQ[pi]->width() : 0));
+                 (titleQ[pi] != null ? titleQ[pi]->width() : 0));
 #else
         int xPos(width() - 2 * borderX());
 #endif
@@ -568,10 +549,6 @@ void YFrameWindow::layoutClient() {
 #endif
                   , w, h));
 
-
-        if (!isFullscreen()) {
-            fClient->constrainSize(w, h, 0);
-        }
         fClient->setGeometry(YRect(0, 0, w, h));
     }
 }
@@ -699,20 +676,35 @@ bool YFrameWindow::Overlaps(bool above) {
     return false;
 }
 
+#warning "should precalculate these"
 int YFrameWindow::borderX() const {
     return
-        isFullscreen() ? 0 :
-        (frameDecors() & fdBorder) ?
-        ((frameDecors() & fdResize) ? wsBorderX : wsDlgBorderX) : 0;
+        isFullscreen() ? 0 : borderXN();
 }
+
+int YFrameWindow::borderXN() const {
+    return
+        (frameDecors() & fdBorder)
+        ? ((frameDecors() & fdResize) ? wsBorderX : wsDlgBorderX)
+        : 0;
+}
+
 int YFrameWindow::borderY() const {
     return
-        isFullscreen() ? 0 :
-        (frameDecors() & fdBorder) ?
-        ((frameDecors() & fdResize) ? wsBorderY : wsDlgBorderY) : 0;
+        isFullscreen() ? 0 : borderYN();
 }
-int YFrameWindow::titleY() const {
+
+int YFrameWindow::borderYN() const {
     return
-        isFullscreen() ? 0 :
-        (frameDecors() & fdTitleBar) ? wsTitleBar : 0;
+        (frameDecors() & fdBorder)
+        ? ((frameDecors() & fdResize) ? wsBorderY : wsDlgBorderY)
+        : 0;
+}
+
+int YFrameWindow::titleY() const {
+    return isFullscreen() ? 0 : titleYN();
+}
+
+int YFrameWindow::titleYN() const {
+    return (frameDecors() & fdTitleBar) ? wsTitleBar : 0;
 }
