@@ -134,7 +134,7 @@ XSV(const char *, mailBoxPath,                  0)
 XSV(const char *, mailCommand,                  "xterm -name pine -title PINE -e pine")
 XSV(const char *, mailClassHint,                "pine.XTerm")
 XSV(const char *, newMailCommand,               0)
-XSV(const char *, lockCommand,                  "xlock")
+XSV(const char *, lockCommand,                  0)
 XSV(const char *, clockCommand,                 "xclock -name icewm -title Clock")
 XSV(const char *, clockClassHint,               "icewm.XClock")
 XSV(const char *, runDlgCommand,                0)
@@ -142,8 +142,8 @@ XSV(const char *, openCommand,                  0)
 XSV(const char *, terminalCommand,              "xterm")
 XSV(const char *, logoutCommand,                0)
 XSV(const char *, logoutCancelCommand,          0)
-XSV(const char *, shutdownCommand,              "sudo /sbin/shutdown -h now")
-XSV(const char *, rebootCommand,                "sudo /sbin/shutdown -r now")
+XSV(const char *, shutdownCommand,              0)
+XSV(const char *, rebootCommand,                0)
 XIV(int, taskBarCPUDelay,                       500)
 XIV(int, taskBarNetSamples,                     20)
 XIV(int, taskBarNetDelay,                       500)
