@@ -538,12 +538,12 @@ void ObjectIconView::activateItem(YIconItem *item) {
 
     if (obj->isFolder()) {
         //if (fork() == 0)
-        //    execl("./icelist", "icelist", path, 0);
+        //    execl("./icelist", "icelist", path, NULL);
         ObjectList *list = new ObjectList(path);
         list->show();
     } else {
         if (fork() == 0)
-            execl("./iceview", "iceview", path, 0);
+            execl("./iceview", "iceview", path, NULL);
     }
     delete path;
 
