@@ -364,14 +364,7 @@ extern "C" void __cxa_pure_virtual() {
     abort();
 }
 
-extern "C" bool __cxa_guard_acquire(volatile bool *pguard) {
-    return *pguard;
-}
-
-extern "C" void __cxa_guard_release(bool * guard) {
-    *guard = false;
-}
-
+/* time to rewrite in C */
 
 #endif
 
