@@ -178,8 +178,8 @@ void YFrameWindow::snapTo(int &wx, int &wy) {
 
 void YFrameWindow::drawMoveSizeFX(int x, int y, int w, int h, bool) {
     if ((movingWindow && opaqueMove) ||
-	(sizingWindow && opaqueResize))
-	return;
+        (sizingWindow && opaqueResize))
+        return;
 
     int const bw((wsBorderX + wsBorderY) / 2);
     int const bo((wsBorderX + wsBorderY) / 4);
@@ -195,8 +195,8 @@ void YFrameWindow::drawMoveSizeFX(int x, int y, int w, int h, bool) {
         gcv.subwindow_mode = IncludeInferiors;
 
         gc = new Graphics(*desktop, GCForeground | GCFunction |
-				    GCGraphicsExposures | GCLineWidth |
-				    GCSubwindowMode, &gcv);
+                                    GCGraphicsExposures | GCLineWidth |
+                                    GCSubwindowMode, &gcv);
     }
 
     gc->drawRect(x + bo, y + bo, w - bw, h - bw);
@@ -232,8 +232,8 @@ int YFrameWindow::handleMoveKeys(const XKeyEvent &key, int &newX, int &newY) {
     else if (k == XK_Next || k == XK_KP_Next)
         newY = My - height() + borderY();
     else if (k == XK_KP_Begin) {
-	newX = (mx + Mx - (int)width()) / 2;
-	newY = (my + My - (int)height()) / 2;
+        newX = (mx + Mx - (int)width()) / 2;
+        newY = (my + My - (int)height()) / 2;
     } else if (k == XK_Return || k == XK_KP_Enter)
         return -1;
     else if (k ==  XK_Escape) {
@@ -419,48 +419,48 @@ void YFrameWindow::outlineMove() {
 
         XWindowEvent(xapp->display(), handle(),
                      KeyPressMask | ExposureMask | 
-		     ButtonPressMask | ButtonReleaseMask | 
-		     PointerMotionMask, &xev);
+                     ButtonPressMask | ButtonReleaseMask | 
+                     PointerMotionMask, &xev);
 
         switch (xev.type) {
-	    case KeyPress: {
-		modifiers = xev.xkey.state;
+            case KeyPress: {
+                modifiers = xev.xkey.state;
 
                 int const ox(xx), oy(yy);
-		int r;
+                int r;
 
                 switch (r = handleMoveKeys(xev.xkey, xx, yy)) {
-		    case 1:
-		    case -2:
-			if (xx != ox || yy != oy) {
-			    drawMoveSizeFX(ox, oy, width(), height());
+                    case 1:
+                    case -2:
+                        if (xx != ox || yy != oy) {
+                            drawMoveSizeFX(ox, oy, width(), height());
 #ifndef LITE
-			    statusMoveSize->setStatus(this, YRect(xx, yy, width(), height()));
+                            statusMoveSize->setStatus(this, YRect(xx, yy, width(), height()));
 #endif
-			    drawMoveSizeFX(xx, yy, width(), height());
-			}
+                            drawMoveSizeFX(xx, yy, width(), height());
+                        }
 
-			if (r == -2)
-			    goto end;
+                        if (r == -2)
+                            goto end;
 
-			break;
+                        break;
 
-		    case 0:
-			break;
+                    case 0:
+                        break;
 
-		    case -1:
-			goto end;
+                    case -1:
+                        goto end;
                 }
 
-		break;
+                break;
             }
 
-	    case ButtonPress:
-	    case ButtonRelease:
-		modifiers = xev.xbutton.state;
-		goto end;
+            case ButtonPress:
+            case ButtonRelease:
+                modifiers = xev.xbutton.state;
+                goto end;
 
-	    case MotionNotify: {
+            case MotionNotify: {
                 int const ox(xx), oy(yy);
 
                 handleMoveMouse(xev.xmotion, xx, yy);
@@ -468,12 +468,12 @@ void YFrameWindow::outlineMove() {
                 if (xx != ox || yy != oy) {
                     drawMoveSizeFX(ox, oy, width(), height());
 #ifndef LITE
-       		    statusMoveSize->setStatus(this, YRect(xx, yy, width(), height()));
+                    statusMoveSize->setStatus(this, YRect(xx, yy, width(), height()));
 #endif
                     drawMoveSizeFX(xx, yy, width(), height());
                 }
 
-		break;
+                break;
             }
         }
     }
@@ -504,7 +504,7 @@ void YFrameWindow::outlineResize() {
         XWindowEvent(xapp->display(), handle(),
                      KeyPressMask | ExposureMask |
                      ButtonPressMask | ButtonReleaseMask | 
-		     PointerMotionMask, &xev);
+                     PointerMotionMask, &xev);
 
         switch (xev.type) {
             case KeyPress: {
@@ -512,50 +512,50 @@ void YFrameWindow::outlineResize() {
                 int r;
 
                 switch (r = handleResizeKeys(xev.xkey, xx, yy, ww, hh,
-					     incX, incY)) {
-		    case -2:
-		    case 1:
-			if (ox != xx || oy != yy || ow != ww || oh != hh) {
-			    drawMoveSizeFX(ox, oy, ow, oh);
+                                             incX, incY)) {
+                    case -2:
+                    case 1:
+                        if (ox != xx || oy != yy || ow != ww || oh != hh) {
+                            drawMoveSizeFX(ox, oy, ow, oh);
 #ifndef LITE
-			    statusMoveSize->setStatus(this, YRect(xx, yy, ww, hh));
+                            statusMoveSize->setStatus(this, YRect(xx, yy, ww, hh));
 #endif
-			    drawMoveSizeFX(xx, yy, ww, hh);
-			}
+                            drawMoveSizeFX(xx, yy, ww, hh);
+                        }
 
-			if (r == -2)
-			    goto end;
+                        if (r == -2)
+                            goto end;
 
-			break;
+                        break;
 
-		    case 0:
-			break;
+                    case 0:
+                        break;
 
-		    case -1:
-			goto end;
+                    case -1:
+                        goto end;
                 }
-		
-		break;
+                
+                break;
             }
 
-	    case ButtonPress:
-	    case ButtonRelease:
-		goto end;
+            case ButtonPress:
+            case ButtonRelease:
+                goto end;
 
-	    case MotionNotify: {
-		int const ox(xx), oy(yy), ow(ww), oh(hh);
+            case MotionNotify: {
+                int const ox(xx), oy(yy), ow(ww), oh(hh);
 
                 handleResizeMouse(xev.xmotion, xx, yy, ww,hh);
 
                 if (ox != xx || oy != yy || ow != ww || oh != hh) {
                     drawMoveSizeFX(ox, oy, ow, oh);
 #ifndef LITE
-       		    statusMoveSize->setStatus(this, YRect(xx, yy, ww, hh));
+                    statusMoveSize->setStatus(this, YRect(xx, yy, ww, hh));
 #endif
                     drawMoveSizeFX(xx, yy, ww, hh);
                 }
 
-		break;
+                break;
             }
         }
     }
@@ -564,7 +564,7 @@ end:
     drawMoveSizeFX(xx, yy, ww, hh);
 
     XSync(xapp->display(), False);
-    setCurrentGeometry(YRect(xx, yy, ww, hh));
+    setCurrentGeometryOuter(YRect(xx, yy, ww, hh));
     XUngrabServer(xapp->display());
 }
 
@@ -604,43 +604,43 @@ void YFrameWindow::manualPlace() {
                    &xev);
 
         switch (xev.type) {
-	    case KeyPress: {
+            case KeyPress: {
                 int const ox(xx), oy(yy);
 
                 int r;
 
                 switch (r = handleMoveKeys(xev.xkey, xx, yy)) {
-		    case 1:
-		    case -2:
-			if (xx != ox || yy != oy) {
-			    drawMoveSizeFX(ox, oy, width(), height());
+                    case 1:
+                    case -2:
+                        if (xx != ox || yy != oy) {
+                            drawMoveSizeFX(ox, oy, width(), height());
 #ifndef LITE
                             statusMoveSize->setStatus(this, YRect(xx, yy, width(), height()));
 #endif
                             drawMoveSizeFX(xx, yy, width(), height());
-			}
+                        }
 
-			if (r == -2)
-			    goto end;
+                        if (r == -2)
+                            goto end;
 
-			break;
+                        break;
 
-		    case 0:
-			break;
+                    case 0:
+                        break;
 
-		    case -1:
-			goto end;
+                    case -1:
+                        goto end;
                 }
 
-		break;
+                break;
             }
-	    
+            
 
-	    case ButtonPress:
-	    case ButtonRelease:
-		goto end;
+            case ButtonPress:
+            case ButtonRelease:
+                goto end;
 
-	    case MotionNotify: {
+            case MotionNotify: {
                 int const ox(xx), oy(yy);
 
                 handleMoveMouse(xev.xmotion, xx, yy);
@@ -652,7 +652,7 @@ void YFrameWindow::manualPlace() {
                     drawMoveSizeFX(xx, yy, width(), height());
                 }
 
-		break;
+                break;
             }
         }
     }
@@ -704,33 +704,33 @@ bool YFrameWindow::handleKey(const XKeyEvent &key) {
             case 0:
                 break;
             case 1:
-                newWidth -= 2 * borderX();
-                newHeight -= 2 * borderY() + titleY();
+                newWidth -= 2 * borderXN();
+                newHeight -= 2 * borderYN() + titleYN();
                 client()->constrainSize(newWidth, newHeight,
                                         ///getLayer(),
                                         YFrameClient::csRound |
                                         (grabX ? YFrameClient::csKeepX : 0) |
                                         (grabY ? YFrameClient::csKeepY : 0));
-                newWidth += 2 * borderX();
-                newHeight += 2 * borderY() + titleY();
+                newWidth += 2 * borderXN();
+                newHeight += 2 * borderYN() + titleYN();
 
                 if (grabX == -1)
                     newX = x() + width() - newWidth;
                 if (grabY == -1)
                     newY = y() + height() - newHeight;
 
-		drawMoveSizeFX(x(), y(), width(), height());
-                setCurrentGeometry(YRect(newX, newY, newWidth, newHeight));
-		drawMoveSizeFX(x(), y(), width(), height());
+                drawMoveSizeFX(x(), y(), width(), height());
+                setCurrentGeometryOuter(YRect(newX, newY, newWidth, newHeight));
+                drawMoveSizeFX(x(), y(), width(), height());
 
 #ifndef LITE
                 statusMoveSize->setStatus(this);
 #endif
                 break;
             case -2:
-		drawMoveSizeFX(x(), y(), width(), height());
-                setCurrentGeometry(YRect(newX, newY, newWidth, newHeight));
-		drawMoveSizeFX(x(), y(), width(), height());
+                drawMoveSizeFX(x(), y(), width(), height());
+                setCurrentGeometryOuter(YRect(newX, newY, newWidth, newHeight));
+                drawMoveSizeFX(x(), y(), width(), height());
                 /* nobreak */
 
             case -1:
@@ -819,7 +819,7 @@ bool YFrameWindow::handleKey(const XKeyEvent &key) {
                     int newX = x();
                     int newY = y();
                     if (manager->getSmartPlace(true, this, newX, newY, width(), height(), getScreen())) {
-                        setPosition(newX, newY);
+                        setCurrentPositionOuter(newX, newY);
                     }
                 }
             } else if (isIconic() || isRollup()) {
@@ -839,12 +839,6 @@ void YFrameWindow::constrainPositionByModifier(int &x, int &y, const XMotionEven
 
     x += borderX();
     y += borderY();
-#if 0
-    if (mask == ShiftMask) {
-        x = x / 4 * 4;
-        y = y / 4 * 4;
-    }
-#endif
     x -= borderX();
     y -= borderY();
 
@@ -864,14 +858,10 @@ void YFrameWindow::constrainMouseToWorkspace(int &x, int &y) {
 bool YFrameWindow::canSize(bool horiz, bool vert) {
     if (isRollup())
         return false;
+    if (isFullscreen())
+        return false;
     if (!(frameFunctions() & ffResize))
         return false;
-#if 0
-#ifndef NO_MWM_HINTS
-    if (!(client()->mwmFunctions() & MWM_FUNC_RESIZE))
-        return false;
-#endif
-#endif
     if (!sizeMaximized) {
         if ((!vert || isMaximizedVert()) &&
             (!horiz || isMaximizedHoriz()))
@@ -883,12 +873,6 @@ bool YFrameWindow::canSize(bool horiz, bool vert) {
 bool YFrameWindow::canMove() {
     if (!(frameFunctions() & ffMove))
         return false;
-#if 0
-#ifndef NO_MWM_HINTS
-    if (!(client()->mwmFunctions() & MWM_FUNC_MOVE))
-        return false;
-#endif
-#endif
     return true;
 }
 
@@ -900,7 +884,7 @@ void YFrameWindow::startMoveSize(int x, int y,
     int sy[] = { -1, -1, -1, 0, 1, 1, 1, 0, 0 };
 
     if (direction >= 0 && direction < (int)(sizeof(sx)/sizeof(sx[0]))) {
-        msg("move size %d %d %d", x, y, direction);
+        MSG(("move size %d %d %d", x, y, direction));
         if (direction == _NET_WM_MOVERESIZE_MOVE) {
             x -= this->x();
             y -= this->y();
@@ -931,12 +915,12 @@ void YFrameWindow::startMoveSize(int doMove, int byMouse,
         buttonDownY = mouseYroot;
 
 #ifdef CONFIG_GUIEVENTS
-	wmapp->signalGuiEvent(geWindowMoved);
+        wmapp->signalGuiEvent(geWindowMoved);
 #endif
         grabPointer = YXApplication::movePointer.handle();
     } else if (!doMove) {
 #ifdef CONFIG_GUIEVENTS
-	wmapp->signalGuiEvent(geWindowSized);
+        wmapp->signalGuiEvent(geWindowSized);
 #endif
 
         if (grabY == -1) {
@@ -958,9 +942,9 @@ void YFrameWindow::startMoveSize(int doMove, int byMouse,
                 grabPointer = YWMApp::sizeLeftPointer.handle();
             else if (grabX == 1)
                 grabPointer = YWMApp::sizeRightPointer.handle();
-	    else
-        	grabPointer = YXApplication::leftPointer.handle();
-	    
+            else
+                grabPointer = YXApplication::leftPointer.handle();
+            
         }
 
         if (grabX == 1)
@@ -1010,14 +994,12 @@ void YFrameWindow::endMoveSize() {
 #endif
 
     if ((movingWindow && opaqueMove) ||
-	(sizingWindow && opaqueResize))
-	drawMoveSizeFX(x(), y(), width(), height());
+        (sizingWindow && opaqueResize))
+        drawMoveSizeFX(x(), y(), width(), height());
 
     movingWindow = 0;
     sizingWindow = 0;
 
-    if (client()) // !!! this can happen at destruction
-        updateNormalSize();
     manager->setWorkAreaMoveWindows(false);
 }
 
@@ -1063,20 +1045,20 @@ void YFrameWindow::moveWindow(int newX, int newY) {
         int mx, my, Mx, My;
         manager->getWorkArea(this, &mx, &my, &Mx, &My);
 
-	newX = clamp(newX, (int)(mx + borderX() - width()),
-			   (int)(Mx - borderX()));
-	newY = clamp(newY, (int)(my + borderY() - height()),
-			   (int)(My - borderY()));
+        newX = clamp(newX, (int)(mx + borderX() - width()),
+                           (int)(Mx - borderX()));
+        newY = clamp(newY, (int)(my + borderY() - height()),
+                           (int)(My - borderY()));
     }
 #endif
 
     if (opaqueMove)
-	drawMoveSizeFX(x(), y(), width(), height());
+        drawMoveSizeFX(x(), y(), width(), height());
 
-    setPosition(newX, newY);
+    setCurrentPositionOuter(newX, newY);
 
     if (opaqueMove)
-	drawMoveSizeFX(x(), y(), width(), height());
+        drawMoveSizeFX(x(), y(), width(), height());
 
 #ifndef LITE
     statusMoveSize->setStatus(this);
@@ -1112,9 +1094,9 @@ void YFrameWindow::handleMotion(const XMotionEvent &motion) {
 
         handleResizeMouse(motion, newX, newY, newWidth, newHeight);
 
-	drawMoveSizeFX(x(), y(), width(), height());
-        setCurrentGeometry(YRect(newX, newY, newWidth, newHeight));
-	drawMoveSizeFX(x(), y(), width(), height());
+        drawMoveSizeFX(x(), y(), width(), height());
+        setCurrentGeometryOuter(YRect(newX, newY, newWidth, newHeight));
+        drawMoveSizeFX(x(), y(), width(), height());
 
 #ifndef LITE
         statusMoveSize->setStatus(this);
