@@ -89,18 +89,6 @@ void DTheme::open() {
 
     YStringArray args(4);
 
-#if 0
-    args.append(app->executable());
-    args.append("--restart");
-///    args.append("-t");
-///    args.append(fTheme);
-
-    if (configArg) {
-    	args.append("-c");
-    	args.append(configArg);
-    }
-
-#endif
     wmapp->restartClient(0, 0);
 }
 
@@ -112,7 +100,6 @@ void ThemesMenu::updatePopup() {
 }
 
 void ThemesMenu::refresh() {
-    //msg("theTheme=%s", themeName);
     removeAll();
 
     char *path;
@@ -168,7 +155,6 @@ YMenuItem * ThemesMenu::newThemeItem(char const *label, char const */*theme*/, c
         YMenuItem *item(new DObjectMenuItem(dtheme));
 
         if (item) {
-            //msg("theme=%s", relThemeName);
             item->setChecked(themeName && 0 == strcmp(themeName, relThemeName));
             return item;
         }
@@ -196,16 +182,16 @@ void ThemesMenu::findThemes(const char *path, YMenu *container) {
         struct dirent *de;
         while ((de = readdir(dir)) != NULL) {
             YMenuItem *im(NULL);
-	    npath = strJoin(dpath, de->d_name, tname, NULL);
+            npath = strJoin(dpath, de->d_name, tname, NULL);
 
             if (npath && access(npath, R_OK) == 0) {
-		if (isFirst) {
-		    isFirst = false;
-//		    if (itemCount())
+                if (isFirst) {
+                    isFirst = false;
+//              if (itemCount())
 //                        addSeparator();
-		    //addLabel(path);
-		    //addSeparator();
-		}
+                    //addLabel(path);
+                    //addSeparator();
+                }
                 char *relThemeName = strJoin(de->d_name, tname, NULL);
                 im = newThemeItem(de->d_name, npath, relThemeName);
                 if (im) {
@@ -246,7 +232,7 @@ void ThemesMenu::findThemes(const char *path, YMenu *container) {
             delete [] subdir;
         }
 
-	closedir(dir);
+        closedir(dir);
     }
 
     delete [] dpath;
@@ -277,7 +263,7 @@ void ThemesMenu::findThemeAlternatives(const char *path, const char *relName,
                         char *tname(newstr(de->d_name, ext - de->d_name));
                         char *relThemeName = strJoin(relName, "/",
                                                      de->d_name, NULL);
-			sub->add(newThemeItem(tname, npath, relThemeName));
+                        sub->add(newThemeItem(tname, npath, relThemeName));
                         delete[] tname;
                         delete[] relThemeName;
                     }
