@@ -1185,7 +1185,7 @@ void YFrameClient::setWinStateHint(long mask, long state) {
 
 #endif
 #ifdef WMSPEC_HINTS
-#warning "hack"
+/// TODO #warning "hack"
     // !!! hack
     Atom a[15];
     int i = 0;
@@ -1611,6 +1611,8 @@ void YFrameClient::getPropertiesList() {
 }
 
 void YFrameClient::configure(const YRect &r, const bool resized) {
+    (void)r;
+    (void)resized;
     MSG(("client geometry %d:%d-%dx%d %d",
          r.x(),
          r.y(),
