@@ -74,6 +74,10 @@ YFrameWindow::YFrameWindow(YWindow *parent): YWindow(parent) {
     normalY = 0;
     normalW = 1;
     normalH = 1;
+    posX = 0;
+    posY = 0;
+    posW = 1;
+    posH = 1;
     iconX = -1;
     iconY = -1;
     movingWindow = 0;
@@ -142,9 +146,9 @@ YFrameWindow::YFrameWindow(YWindow *parent): YWindow(parent) {
     else {
         fMinimizeButton = new YFrameButton(fTitleBar, this,
 #ifndef CONFIG_PDA
-					   actionMinimize, actionHide);
+                                           actionMinimize, actionHide);
 #else
-					   actionMinimize, 0);
+                                           actionMinimize, 0);
 #endif
         //fMinimizeButton->setWinGravity(NorthEastGravity);
         fMinimizeButton->setToolTip(_("Minimize"));
@@ -318,6 +322,19 @@ void YFrameWindow::doManage(YFrameClient *clientw) {
     PRECONDITION(clientw != 0);
     fClient = clientw;
 
+    {
+        int x = client()->x();
+        int y = client()->y();
+        int w = client()->width();
+        int h = client()->height();
+
+        XSizeHints *sh = client()->sizeHints();
+        normalX = x;
+        normalY = y;
+        normalW = sh ? (w - sh->base_width) / sh->width_inc : w;
+        normalH = sh ? (h - sh->base_height) / sh->height_inc : h ;
+    }
+
 #ifndef LITE
     updateIcon();
 #endif
@@ -588,18 +605,18 @@ void YFrameWindow::unmanage(bool reparent) {
 
         int posX, posY, posWidth, posHeight;
 
-        getNormalGeometry(&posX, &posY, &posWidth, &posHeight);
+        getNormalGeometryInner(&posX, &posY, &posWidth, &posHeight);
         if (gx < 0)
-            posX -= borderX();
+            posX -= borderXN();
         else if (gx > 0)
-            posX += borderX() - 2 * client()->getBorder();
+            posX += borderXN() - 2 * client()->getBorder();
         if (gy < 0)
-            posY -= borderY() + titleY();
+            posY -= borderYN();
         else if (gy > 0)
-            posY += borderY() - 2 * client()->getBorder();
+            posY += borderYN() - 2 * client()->getBorder();
 
-	if (reparent)
-		client()->reparent(manager, posX, posY);
+        if (reparent)
+            client()->reparent(manager, posX, posY);
 
         client()->setSize(posWidth, posHeight);
 
@@ -801,67 +818,26 @@ void YFrameWindow::configureClient(const XConfigureRequestEvent &configureReques
 }
 
 void YFrameWindow::configureClient(int cx, int cy, int cwidth, int cheight) {
-    cx -= borderX();
-    cy -= borderY() + titleY();
-    cwidth += 2 * borderX();
-    cheight += 2 * borderY() + titleY();
-#if 1
-    // !!! should be an option
-    if (cx != x() || cy != y() ||
-        cwidth != width() || cheight != height())
-    {
-        if (isMaximized()) {
-            fWinState &= ~(WinStateMaximizedVert | WinStateMaximizedHoriz);
-            if (fMaximizeButton) {
-                fMaximizeButton->setActions(actionMaximize, actionMaximizeVert);
-                fMaximizeButton->setToolTip(_("Maximize"));
-            }
-        }
-    }
-#endif
-
     MSG(("setting geometry (%d:%d %dx%d)", cx, cy, cwidth, cheight));
+    cy -= titleYN();
+#warning "alternative configure mechanism would be nice"
+    if (isFullscreen())
+        return;
+    else {
+        int posX, posY, posW, posH;
+        getNormalGeometryInner(&posX, &posY, &posW, &posH);
 
-    if (isIconic()) {
-        cx += borderX();
-        cy += borderY() + titleY();
-        cwidth -= 2 * borderX();
-        cheight -= 2 * borderY() + titleY();
-        client()->setGeometry(YRect(0, 0, cwidth, cheight));
-
-        int nx = cx;
-        int ny = cy;
-        int nw = cwidth;
-        int nh = cheight;
-        XSizeHints *sh = client()->sizeHints();
-
-	/// this needs fixing (see updateNormalSize)
-        bool cxw = true;
-        bool cy = true;
-        bool ch = true;
-
-        if (isMaximizedHoriz())
-            cxw = false;
-        if (isMaximizedVert())
-            cy = ch = false;
-        if (isRollup())
-            ch = false;
-
-        MSG(("isIconic %d %d %d", cxw, cy, ch));
-
-        if (cxw) {
-            normalX = nx;
-            normalW = sh ? (nw - sh->base_width) / sh->width_inc : nw;
+        if (isMaximizedVert() || isRollup()) {
+            cy = posY;
+            cheight = posH;
+        }
+        if (isMaximizedHoriz()) {
+            cx = posX;
+            cwidth = posW;
         }
-        if (cy)
-            normalY = ny;
-        if (ch)
-            normalH = sh ? (nh - sh->base_height) / sh->height_inc : nh;
-    } else if (isRollup()) {
-        //!!!
-    } else {
-        setCurrentGeometry(YRect(cx, cy, cwidth, cheight));
     }
+
+    setNormalGeometryInner(cx, cy, cwidth, cheight);
 }
 
 void YFrameWindow::handleClick(const XButtonEvent &up, int /*count*/) {
@@ -1050,6 +1026,7 @@ void YFrameWindow::setAbove(YFrameWindow *aboveFrame) {
         if (debug_z) dumpZorder("after setAbove", this, aboveFrame);
 #endif
     }
+    manager->updateFullscreenLayer();
 }
 
 void YFrameWindow::setBelow(YFrameWindow *belowFrame) {
@@ -1270,16 +1247,6 @@ void YFrameWindow::actionPerformed(YAction *action, unsigned int modifiers) {
                 return ;
             }
         }
-#ifdef CONFIG_TRAY
-#if 0
-        for (int o(0); o < WinTrayOptionCount; o++) {
-            if (action == trayOptionActionSet[o]) {
-                wmSetTrayOption(o);
-                return;
-            }
-        }
-#endif
-#endif
         wmapp->actionPerformed(action, modifiers);
     }
 }
@@ -1301,7 +1268,6 @@ void YFrameWindow::wmToggleDoNotCover() {
 #endif
 
 void YFrameWindow::wmToggleFullscreen() {
-    /// TODO
     if (isFullscreen()) {
         setState(WinStateFullscreen, 0);
     } else {
@@ -1366,8 +1332,6 @@ void YFrameWindow::wmMinimize() {
 #endif
         setState(WinStateMinimized, 0);
     } else {
-        //if (!canMinimize())
-        //    return ;
 #ifdef CONFIG_GUIEVENTS
         wmapp->signalGuiEvent(geWindowMin);
 #endif
@@ -1381,12 +1345,12 @@ void YFrameWindow::wmMinimize() {
 void YFrameWindow::minimizeTransients() {
     for (YFrameWindow *w = transient(); w; w = w->nextTransient()) {
 // Since a) YFrameWindow::setState is too heavy but b) we want to save memory
-	MSG(("> isMinimized: %d\n", w->isMinimized()));
+        MSG(("> isMinimized: %d\n", w->isMinimized()));
         if (w->isMinimized())
             w->fWinState|= WinStateWasMinimized;
         else
             w->fWinState&= ~WinStateWasMinimized;
-	MSG(("> wasMinimized: %d\n", w->wasMinimized()));
+        MSG(("> wasMinimized: %d\n", w->wasMinimized()));
         if (!w->isMinimized()) w->wmMinimize();
     }
 }
@@ -1400,12 +1364,12 @@ void YFrameWindow::restoreMinimizedTransients() {
 void YFrameWindow::hideTransients() {
     for (YFrameWindow *w = transient(); w; w = w->nextTransient()) {
 // See YFrameWindow::minimizeTransients() for reason
-	MSG(("> isHidden: %d\n", w->isHidden()));
+        MSG(("> isHidden: %d\n", w->isHidden()));
         if (w->isHidden())
             w->fWinState|= WinStateWasHidden;
         else
             w->fWinState&= ~WinStateWasHidden;
-	MSG(("> was visible: %d\n", w->wasHidden());
+        MSG(("> was visible: %d\n", w->wasHidden());
         if (!w->isHidden()) w->wmHide());
     }
 }
@@ -1427,9 +1391,6 @@ void YFrameWindow::DoMaximize(long flags) {
                  WinStateMaximizedHoriz |
                  WinStateMinimized, 0);
     } else {
-        //if (!canMaximize())
-        //    return ;
-
 #ifdef CONFIG_GUIEVENTS
         wmapp->signalGuiEvent(geWindowMax);
 #endif
@@ -1450,8 +1411,6 @@ void YFrameWindow::wmMaximizeVert() {
 #endif
         setState(WinStateMaximizedVert, 0);
     } else {
-        //if (!canMaximize())
-        //    return ;
 #ifdef CONFIG_GUIEVENTS
         wmapp->signalGuiEvent(geWindowMax);
 #endif
@@ -1466,8 +1425,6 @@ void YFrameWindow::wmMaximizeHorz() {
 #endif
         setState(WinStateMaximizedHoriz, 0);
     } else {
-        //if (!canMaximize())
-        //    return ;
 #ifdef CONFIG_GUIEVENTS
         wmapp->signalGuiEvent(geWindowMax);
 #endif
@@ -1498,9 +1455,6 @@ void YFrameWindow::wmHide() {
 #endif
         setState(WinStateHidden, 0);
     } else {
-        //if (!canHide())
-        //    return ;
-
 #ifdef CONFIG_GUIEVENTS
         wmapp->signalGuiEvent(geWindowHide);
 #endif
@@ -1543,8 +1497,8 @@ void YFrameWindow::doRaise() {
     if (this != manager->top(getActiveLayer())) {
         setAbove(manager->top(getActiveLayer()));
 
-	for (YFrameWindow * w (transient()); w; w = w->nextTransient())
-	    w->doRaise();
+        for (YFrameWindow * w (transient()); w; w = w->nextTransient())
+            w->doRaise();
 
 #ifdef DEBUG
         if (debug_z) dumpZorder("wmRaise after raise: ", this);
@@ -1585,7 +1539,7 @@ void YFrameWindow::wmConfirmKill() {
         msgbox->setTitle(title);
         delete title; title = 0;
         msgbox->setText(_("WARNING! All unsaved changes will be lost when\n"
-			  "this client is killed. Do you wish to proceed?"));
+                          "this client is killed. Do you wish to proceed?"));
         msgbox->autoSize();
         msgbox->setMsgBoxListener(this);
         msgbox->showFocused();
@@ -1712,7 +1666,8 @@ void YFrameWindow::focusOnMap() {
 }
 
 void YFrameWindow::wmShow() {
-   // recover lost (offscreen) windows !!! (unify with code below)
+    // recover lost (offscreen) windows !!! (unify with code below)
+#warning "this is really broken"
     if (x() >= int(manager->width()) ||
         y() >= int(manager->height()) ||
         x() <= - int(width()) ||
@@ -1730,7 +1685,7 @@ void YFrameWindow::wmShow() {
             newX = int(- borderX());
         if (newY < int(- borderY()))
             newY = int(- borderY());
-        setPosition(newX, newY);
+        setCurrentPositionOuter(newX, newY);
     }
 
     setState(WinStateHidden | WinStateMinimized, 0);
@@ -1761,7 +1716,7 @@ void YFrameWindow::focus(bool canWarp) {
             newX = int(- borderX());
         if (newY < int(- borderY()))
             newY = int(- borderY());
-        setPosition(newX, newY);
+        setCurrentPositionOuter(newX, newY);
     }
 
     //    if (isFocusable())
@@ -1860,21 +1815,21 @@ void YFrameWindow::paint(Graphics &g, const YRect &/*r*/) {
             int t = (frameDecors() & fdResize) ? 0 : 1;
 
             if ((frameT[t][n] != null || TEST_GRADIENT(rgbFrameT[t][n] != null)) &&
-		(frameL[t][n] != null || TEST_GRADIENT(rgbFrameL[t][n] != null)) &&
-		(frameR[t][n] != null || TEST_GRADIENT(rgbFrameR[t][n] != null)) &&
-		(frameB[t][n] != null || TEST_GRADIENT(rgbFrameB[t][n] != null)) &&
-		frameTL[t][n] != null && frameTR[t][n] != null &&
-		frameBL[t][n] != null && frameBR[t][n] != null) {
-		int const xtl(frameTL[t][n]->width());
-		int const ytl(frameTL[t][n]->height());
-		int const xtr(frameTR[t][n]->width());
-		int const ytr(frameTR[t][n]->height());
-		int const xbl(frameBL[t][n]->width());
-		int const ybl(frameBL[t][n]->height());
-		int const xbr(frameBR[t][n]->width());
-		int const ybr(frameBR[t][n]->height());
+                (frameL[t][n] != null || TEST_GRADIENT(rgbFrameL[t][n] != null)) &&
+                (frameR[t][n] != null || TEST_GRADIENT(rgbFrameR[t][n] != null)) &&
+                (frameB[t][n] != null || TEST_GRADIENT(rgbFrameB[t][n] != null)) &&
+                frameTL[t][n] != null && frameTR[t][n] != null &&
+                frameBL[t][n] != null && frameBR[t][n] != null) {
+                int const xtl(frameTL[t][n]->width());
+                int const ytl(frameTL[t][n]->height());
+                int const xtr(frameTR[t][n]->width());
+                int const ytr(frameTR[t][n]->height());
+                int const xbl(frameBL[t][n]->width());
+                int const ybl(frameBL[t][n]->height());
+                int const xbr(frameBR[t][n]->width());
+                int const ybr(frameBR[t][n]->height());
 
-		int const cx(width()/2);
+                int const cx(width()/2);
                 int const cy(height()/2);
 
                 int mxtl = min(xtl, cx);
@@ -1886,51 +1841,51 @@ void YFrameWindow::paint(Graphics &g, const YRect &/*r*/) {
                 int mxbr = min(xbr, cx);
                 int mybr = min(ybr, cy);
 
-		g.copyPixmap(frameTL[t][n], 0, 0,
-			     mxtl, mytl, 0, 0);
-		g.copyPixmap(frameTR[t][n], max(0, (int)xtr - (int)cx), 0,
-			     mxtr, mytr,
-			     width() - mxtr, 0);
-		g.copyPixmap(frameBL[t][n], 0, max(0, (int)ybl - (int)cy),
-			     mxbl, mybl,
-			     0, height() - mybl);
-		g.copyPixmap(frameBR[t][n],
-			     max(0, (int)xbr - (int)cx), max(0, (int)ybr - (int)cy),
-			     mxbr, mybr,
-			     width() - mxbr, height() - mybr);
+                g.copyPixmap(frameTL[t][n], 0, 0,
+                             mxtl, mytl, 0, 0);
+                g.copyPixmap(frameTR[t][n], max(0, (int)xtr - (int)cx), 0,
+                             mxtr, mytr,
+                             width() - mxtr, 0);
+                g.copyPixmap(frameBL[t][n], 0, max(0, (int)ybl - (int)cy),
+                             mxbl, mybl,
+                             0, height() - mybl);
+                g.copyPixmap(frameBR[t][n],
+                             max(0, (int)xbr - (int)cx), max(0, (int)ybr - (int)cy),
+                             mxbr, mybr,
+                             width() - mxbr, height() - mybr);
 
-		if (width() > (mxtl + mxtr))
-		    if (frameT[t][n] != null) g.repHorz(frameT[t][n],
-			mxtl, 0, width() - mxtl - mxtr);
+                if (width() > (mxtl + mxtr))
+                    if (frameT[t][n] != null) g.repHorz(frameT[t][n],
+                        mxtl, 0, width() - mxtl - mxtr);
 #ifdef CONFIG_GRADIENTS
-		    else g.drawGradient(rgbFrameT[t][n],
-			mxtl, 0, width() - mxtl - mxtr, borderY());
+                    else g.drawGradient(rgbFrameT[t][n],
+                        mxtl, 0, width() - mxtl - mxtr, borderY());
 #endif
 
-		if (height() > (mytl + mybl))
-		    if (frameL[t][n] != null) g.repVert(frameL[t][n],
-			0, mytl, height() - mytl - mybl);
+                if (height() > (mytl + mybl))
+                    if (frameL[t][n] != null) g.repVert(frameL[t][n],
+                        0, mytl, height() - mytl - mybl);
 #ifdef CONFIG_GRADIENTS
-		    else g.drawGradient(rgbFrameL[t][n],
-			0, mytl, borderX(), height() - mytl - mybl);
+                    else g.drawGradient(rgbFrameL[t][n],
+                        0, mytl, borderX(), height() - mytl - mybl);
 #endif
 
-		if (height() > (mytr + mybr))
-		    if (frameR[t][n] != null) g.repVert(frameR[t][n],
-			width() - borderX(), mytr, height() - mytr - mybr);
+                if (height() > (mytr + mybr))
+                    if (frameR[t][n] != null) g.repVert(frameR[t][n],
+                        width() - borderX(), mytr, height() - mytr - mybr);
 #ifdef CONFIG_GRADIENTS
-		    else g.drawGradient(rgbFrameR[t][n],
-			width() - borderX(), mytr,
-			borderX(), height() - mytr - mybr);
+                    else g.drawGradient(rgbFrameR[t][n],
+                        width() - borderX(), mytr,
+                        borderX(), height() - mytr - mybr);
 #endif
 
-		if (width() > (mxbl + mxbr))
-		    if (frameB[t][n] != null) g.repHorz(frameB[t][n],
-			mxbl, height() - borderY(), width() - mxbl - mxbr);
+                if (width() > (mxbl + mxbr))
+                    if (frameB[t][n] != null) g.repHorz(frameB[t][n],
+                        mxbl, height() - borderY(), width() - mxbl - mxbr);
 #ifdef CONFIG_GRADIENTS
-		    else g.drawGradient(rgbFrameB[t][n],
-			mxbl, height() - borderY(),
-			width() - mxbl - mxbr, borderY());
+                    else g.drawGradient(rgbFrameB[t][n],
+                        mxbl, height() - borderY(),
+                        width() - mxbl - mxbr, borderY());
 #endif
 
             } else {
@@ -2290,7 +2245,7 @@ YIcon *newClientIcon(int count, int reclen, long * elem) {
             MSG(("Invalid pixmap size for subicon #%d: %dx%d", i, w, h));
             continue;
         }
-	MSG(("client icon: %ld %d %d %d %d", pixmap, w, h, depth, xapp->depth()));
+        MSG(("client icon: %ld %d %d %d %d", pixmap, w, h, depth, xapp->depth()));
         if (depth == 1) {
             ref<YPixmap> img(new YPixmap(w, h));
             Graphics g(img, 0, 0);
@@ -2416,7 +2371,7 @@ void YFrameWindow::updateIcon() {
     if (fTaskBarApp) fTaskBarApp->repaint();
 #endif
     if (windowList && fWinListItem)
-    	windowList->getList()->repaintItem(fWinListItem);
+        windowList->getList()->repaintItem(fWinListItem);
 }
 #endif
 
@@ -2453,7 +2408,7 @@ void YFrameWindow::addAsTransient() {
 
         if (fOwner) {
             MSG(("transient for 0x%lX: 0x%lX", groupLeader, fOwner));
-	    PRECONDITION(fOwner->transient() != this);
+            PRECONDITION(fOwner->transient() != this);
 
             fNextTransient = fOwner->transient();
             fOwner->setTransient(this);
@@ -2461,7 +2416,7 @@ void YFrameWindow::addAsTransient() {
             if (getActiveLayer() < fOwner->getActiveLayer()) {
                 setRequestedLayer(fOwner->getActiveLayer());
             }
-	}
+        }
     }
 }
 
@@ -2470,11 +2425,11 @@ void YFrameWindow::removeAsTransient() {
         MSG(("removeAsTransient"));
 
         for (YFrameWindow *curr = fOwner->transient(), *prev = NULL;
-	     curr; prev = curr, curr = curr->nextTransient()) {
-	    if (curr == this) {
+             curr; prev = curr, curr = curr->nextTransient()) {
+            if (curr == this) {
                 if (prev) prev->setNextTransient(nextTransient());
                 else fOwner->setTransient(nextTransient());
-		break;
+                break;
             }
         }
 
@@ -2629,7 +2584,7 @@ void YFrameWindow::updateLayer(bool restack) {
     {
         YFrameWindow *focus = manager->getFocus();
         while (focus) {
-            if (focus == this && isFullscreen() && manager->fullscreenEnabled()) {
+            if (focus == this && isFullscreen() && manager->fullscreenEnabled() && !canRaise()) {
                 newLayer = WinLayerFullscreen;
                 break;
             }
@@ -2646,7 +2601,7 @@ void YFrameWindow::updateLayer(bool restack) {
             client()->setWinLayerHint(fWinRequestedLayer);
 
         if (limitByDockLayer &&
-	   (getActiveLayer() == WinLayerDock || oldLayer == WinLayerDock))
+           (getActiveLayer() == WinLayerDock || oldLayer == WinLayerDock))
             manager->updateWorkArea();
 
         YFrameWindow *w = transient();
@@ -2769,207 +2724,223 @@ bool YFrameWindow::inWorkArea() const {
     return true;
 }
 
-void YFrameWindow::getNormalGeometry(int *x, int *y, int *w, int *h) {
+void YFrameWindow::getNormalGeometryInner(int *x, int *y, int *w, int *h) {
     XSizeHints *sh = client()->sizeHints();
-    bool cxw = true;
-    bool cy = true;
-    bool ch = true;
-
-    *x = this->x() + borderX();
-    *y = this->y() + borderY() + titleY();
-    *w = client()->width();
-    *h = client()->height();
-
-    if (isIconic())
-        cxw = cy = ch = false;
-    else {
-        if (isMaximizedHoriz())
-            cxw = false;
-        if (isMaximizedVert())
-            cy = ch = false;
-        if (isRollup())
-            ch = false;
-    }
-    if (!cxw) {
-        if (x) *x = normalX;
-        if (w) *w = sh ? normalW * sh->width_inc + sh->base_width : normalW;
-    }
-    if (!cy)
-        if (y) *y = normalY + titleY();
-    if (!ch)
-        if (h) *h = sh ? normalH * sh->height_inc + sh->base_height : normalH;
+    *x = normalX;
+    *y = normalY;
+    *w = sh ? normalW * sh->width_inc + sh->base_width : normalW;
+    *h = sh ? normalH * sh->height_inc + sh->base_height : normalH;
 }
 
-void YFrameWindow::setNormalGeometry(int x, int y, int w, int h) {
+void YFrameWindow::setNormalGeometryOuter(int x, int y, int w, int h) {
+    x += borderXN();
+    y += borderYN();
+    w -= 2 * borderXN();
+    h -= 2 * borderYN() + titleYN();
+    setNormalGeometryInner(x, y, w, h);
+}
+
+void YFrameWindow::setNormalPositionOuter(int x, int y) {
     XSizeHints *sh = client()->sizeHints();
-    normalX = x + borderX();
-    normalY = y + borderY();
-    normalW = sh ? (w - 2 * borderX() - sh->base_width) / sh->width_inc : w;
-    normalH = sh ? (h - 2 * borderY() - titleY() - sh->base_height) / sh->height_inc : h ;
+    x += borderXN();
+    y += borderYN();
+    int w = sh ? normalW * sh->width_inc + sh->base_width : normalW;
+    int h = sh ? normalH * sh->height_inc + sh->base_height : normalH;
+    setNormalGeometryInner(x, y, w, h);
+}
+
+void YFrameWindow::setNormalGeometryInner(int x, int y, int w, int h) {
+    XSizeHints *sh = client()->sizeHints();
+    normalX = x;
+    normalY = y;
+    normalW = sh ? (w - sh->base_width) / sh->width_inc : w;
+    normalH = sh ? (h - sh->base_height) / sh->height_inc : h ;
+
+    updateDerivedSize();
     updateLayout();
 }
 
-void YFrameWindow::updateNormalSize() {
-    /// this doesn't work for initial mapping!!! FIX
-    if (isIconic()) {
-        iconX = this->x();
-        iconY = this->y();
-    } else {
-        int nx = this->x() + borderX();
-        int ny = this->y() + borderY();
-        int nw = client()->width();
-        int nh = client()->height();
-        XSizeHints *sh = client()->sizeHints();
-        bool cx = true;
-        bool cy = true;
-        bool cw = true;
-        bool ch = true;
+void YFrameWindow::updateDerivedSize() {
+    XSizeHints *sh = client()->sizeHints();
 
-        if (isFullscreen())
-            cy = ch = cx = cw = false;
-        if (isMaximizedHoriz())
-            cx = cw = false;
-        if (isMaximizedVert())
-            cy = ch = false;
-        if (isRollup())
-            ch = false;
+    int nx = normalX;
+    int ny = normalY;
+    int nw = sh ? normalW * sh->width_inc + sh->base_width : normalW;
+    int nh = sh ? normalH * sh->height_inc + sh->base_height : normalH;
 
-        if (cx) {
-            normalX = nx;
-        }
-        if (cw) {
-            normalW = sh ? (nw - sh->base_width) / sh->width_inc : nw;
-        }
-        if (cy) {
-            normalY = ny;
-        }
-        if (ch) {
-            normalH = sh ? (nh - sh->base_height) / sh->height_inc : nh;
+    int xiscreen = manager->getScreenForRect(nx,
+                                             ny,
+                                             nw,
+                                             nh);
+    int mx, my, Mx, My;
+    manager->getWorkArea(this, &mx, &my, &Mx, &My, xiscreen);
+    int Mw = Mx - mx;
+    int Mh = My - my;
+
+    Mh -= titleYN();
+
+    if (1) { // aspect of maximization
+        int aMw, aMh;
+        aMw = Mw;
+        aMh = Mh;
+
+        client()->constrainSize(aMw, aMh, YFrameClient::csKeepX);
+        if (aMh < Mh) {
+            Mh = aMh;
+        } else {
+            client()->constrainSize(aMw, aMh, YFrameClient::csKeepY);
+            if (aMw < Mw) {
+                Mw = aMw;
+            }
         }
     }
 
-    MSG(("updateNormalSize: (%d:%d %dx%d) icon (%d:%d)",
-    	 normalX, normalY, normalW, normalH, iconX, iconY));
+    if (isMaximizedHoriz()) {
+        nw = Mw;
+        if (considerHorizBorder) {
+            nw -= 2 * borderXN();
+        }
+    }
+
+    if (isMaximizedVert()) {
+        nh = Mh;
+        if (considerVertBorder) {
+            nh -= 2 * borderYN();
+        }
+    }
+
+    if (isMaximizedHoriz() || isMaximizedVert()) {
+        client()->constrainSize(nw, nh, ///getLayer(),
+                                (nw >= Mw) ? YFrameClient::csKeepY
+                                : YFrameClient::csKeepX);
+    }
+    if (isMaximizedHoriz()) {
+        nx = mx;
+
+        nw += 2 * borderXN();
+        if (centerMaximizedWindows && !(sh && (sh->flags & PMaxSize)))
+            nx = mx + (Mw - nw) / 2;
+        else if (!considerHorizBorder)
+            nx -= borderXN();
+
+    } else {
+        nx -= borderXN();
+        nw += 2 * borderXN();
+    }
+
+    if (isMaximizedVert()) {
+        ny = my;
+
+        nh += 2 * borderYN();
+        if (centerMaximizedWindows && !(sh && (sh->flags & PMaxSize)))
+            ny = my + (Mh - nh) / 2;
+        else if (!considerVertBorder)
+            ny -= borderYN();
+    } else {
+        ny -= borderYN();
+        nh += 2 * borderYN();
+    }
+
+    posX = nx;
+    posY = ny;
+    posW = nw;
+    posH = nh + titleYN();
 }
 
-void YFrameWindow::updateMaximizedSize() {
+void YFrameWindow::updateNormalSize() {
+    XSizeHints *sh = client()->sizeHints();
 
+    bool cx = true;
+    bool cy = true;
+    bool cw = true;
+    bool ch = true;
+
+    if (isFullscreen() || isIconic())
+        cy = ch = cx = cw = false;
+    if (isMaximizedHoriz())
+        cx = cw = false;
+    if (isMaximizedVert())
+        cy = ch = false;
+    if (isRollup())
+        ch = false;
+
+    if (cx)
+        normalX = posX + borderXN();
+    if (cy)
+        normalY = posY + borderYN();
+    if (cw) {
+        normalW = posW - 2 * borderXN();
+        normalW = sh ? (normalW - sh->base_width) / sh->width_inc : normalW;
+    }
+    if (ch) {
+        normalH = posH - (2 * borderYN() + titleYN());
+        normalH = sh ? (normalH - sh->base_height) / sh->height_inc : normalH;
+    }
 }
 
-void YFrameWindow::setCurrentGeometry(YRect newSize) {
-    setGeometry(newSize);
+void YFrameWindow::setCurrentGeometryOuter(YRect newSize) {
+    setWindowGeometry(newSize);
+
+    bool cx = true;
+    bool cy = true;
+    bool cw = true;
+    bool ch = true;
+
+    if (isFullscreen() || isIconic())
+        cy = ch = cx = cw = false;
+    if (isRollup())
+        ch = false;
+
+    if (cx)
+        posX = x();
+    if (cy)
+        posY = y();
+    if (cw)
+        posW = width();
+    if (ch)
+        posH = height();
+
+    if (isIconic()) {
+        iconX = x();
+        iconY = y();
+    }
+
     updateNormalSize();
 }
 
+void YFrameWindow::setCurrentPositionOuter(int x, int y) {
+    setCurrentGeometryOuter(YRect(x, y, width(), height()));
+}
+
 void YFrameWindow::updateLayout() {
     if (isIconic()) {
         if (iconX == -1 && iconY == -1)
             manager->getIconPosition(this, &iconX, &iconY);
 
-	setGeometry(YRect(iconX, iconY, fMiniIcon->width(), fMiniIcon->height()));
+        setWindowGeometry(YRect(iconX, iconY, fMiniIcon->width(), fMiniIcon->height()));
     } else {
-	XSizeHints *sh(client()->sizeHints());
-
-	int nx(normalX);
-	int ny(normalY);
-
-	int nw(sh ? normalW * sh->width_inc + sh->base_width
-		  : normalW);
-	int nh(sh ? normalH * sh->height_inc + sh->base_height
-		  : normalH);
-
-        int xiscreen = manager->getScreenForRect(nx,
-                                                 ny,
-                                                 nw,
-                                                 nh);
+        int xiscreen = manager->getScreenForRect(posX,
+                                                 posY,
+                                                 posW,
+                                                 posH);
 
         int dx, dy, dw, dh;
         manager->getScreenGeometry(&dx, &dy, &dw, &dh, xiscreen);
 
         if (isFullscreen()) {
-            nw = dw;
-            nh = dh;
-            nx = dx;
-            ny = dy;
+            setWindowGeometry(YRect(dx, dy, dw, dh));
         } else {
-            int mx, my, Mx, My;
-            manager->getWorkArea(this, &mx, &my, &Mx, &My, xiscreen);
-            int Mw = Mx - mx;
-            int Mh = My - my;
-
-            Mh -= titleY();
-
-            if (1) { // aspect of maximization
-                int aMw, aMh;
-                aMw = Mw;
-                aMh = Mh;
-
-                client()->constrainSize(aMw, aMh, YFrameClient::csKeepX);
-                if (aMh < Mh) {
-                    Mh = aMh;
-                } else {
-                    client()->constrainSize(aMw, aMh, YFrameClient::csKeepY);
-                    if (aMw < Mw) {
-                        Mw = aMw;
-                    }
-                }
-            }
-
-            if (isMaximizedHoriz()) {
-                nw = Mw;
-                if (considerHorizBorder) {
-                    nw -= 2 * borderX();
-                }
-            }
-
-            if (isMaximizedVert()) {
-                nh = Mh;
-                if (considerVertBorder) {
-                    nh -= 2 * borderY();
-                }
-            }
-
-            client()->constrainSize(nw, nh, ///getLayer(),
-                                    (nw >= Mw) ? YFrameClient::csKeepY
-                                              : YFrameClient::csKeepX);
-            if (isMaximizedHoriz()) {
-                nx = mx;
-
-                nw += 2 * borderX();
-                if (centerMaximizedWindows && !(sh && (sh->flags & PMaxSize)))
-                    nx = mx + (Mw - nw) / 2;
-                else if (!considerHorizBorder)
-                    nx -= borderX();
 
+            if (isRollup()) {
+                setWindowGeometry(YRect(posX, posY, posW, 2 * borderY() + titleY()));
             } else {
-                nx -= borderX();
-                nw += 2 * borderX();
+                setWindowGeometry(YRect(posX, posY, posW, posH));
             }
-
-            if (isMaximizedVert()) {
-                ny = my;
-
-                nh += 2 * borderY();
-                if (centerMaximizedWindows && !(sh && (sh->flags & PMaxSize)))
-                    ny = my + (Mh - nh) / 2;
-                else if (!considerVertBorder)
-                    ny -= borderY();
-            } else {
-                ny -= borderY();
-                nh += 2 * borderY();
-            }
-
-            if (isRollup())
-                nh = 2 * borderY();
         }
-        MSG(("updateLayout: %d:%d %dx%d", nx, ny, nw, nh + titleY()));
-	setGeometry(YRect(nx, ny, nw, nh + titleY()));
     }
 }
 
 void YFrameWindow::setState(long mask, long state) {
-    updateNormalSize(); // !!! fix this to move below (or remove totally)
-
     long fOldState = fWinState;
     long fNewState = (fWinState & ~mask) | (state & mask);
 
@@ -3004,6 +2975,7 @@ void YFrameWindow::setState(long mask, long state) {
                 fMaximizeButton->setToolTip(_("Maximize"));
             }
         }
+        updateDerivedSize();
     }
     if ((fOldState ^ fNewState) & WinStateMinimized) {
         MSG(("WinStateMinimized: %d", isMaximized()));
@@ -3025,6 +2997,7 @@ void YFrameWindow::setState(long mask, long state) {
 #ifdef CONFIG_TASKBAR
         updateTaskBar();
 #endif
+        layoutResizeIndicators();
         manager->focusLastWindow();
     }
     if ((fOldState ^ fNewState) & WinStateRollup) {
@@ -3037,6 +3010,7 @@ void YFrameWindow::setState(long mask, long state) {
             }
             fRollupButton->repaint();
         }
+        layoutResizeIndicators();
     }
     if ((fOldState ^ fNewState) & WinStateHidden) {
         MSG(("WinStateHidden: %d", isHidden()));
@@ -3052,9 +3026,7 @@ void YFrameWindow::setState(long mask, long state) {
     }
     updateState();
     updateLayer();
-    //if ((fOldState ^ fNewState) & WinStateFullscreen) {
     manager->updateFullscreenLayer();
-    //}
     updateLayout();
 
 #ifdef CONFIG_SHAPE
@@ -3083,7 +3055,7 @@ void YFrameWindow::setSticky(bool sticky) {
     windowList->updateWindowListApp(fWinListItem);
 #endif
     if (affectsWorkArea())
-	manager->updateWorkArea();
+        manager->updateWorkArea();
 }
 
 #if DO_NOT_COVER_OLD
@@ -3091,9 +3063,9 @@ void YFrameWindow::setDoNotCover(bool doNotCover) {
     fWinOptionMask &= ~foDoNotCover;
 
     if (doNotCover) {
-	fFrameOptions |= foDoNotCover;
+        fFrameOptions |= foDoNotCover;
     } else {
-	fFrameOptions &= ~foDoNotCover;
+        fFrameOptions &= ~foDoNotCover;
     }
     manager->updateWorkArea();
 }
@@ -3152,7 +3124,7 @@ void YFrameWindow::updateTaskBar() {
     if (taskBar && fManaged && taskBar->trayPane()) {
         if (!isHidden() &&
             !(frameOptions() & foIgnoreTaskBar) &&
-	    (getTrayOption() != WinTrayIgnore))
+            (getTrayOption() != WinTrayIgnore))
             if (trayShowAllWindows || visibleOn(manager->activeWorkspace()))
                 needTrayApp = true;
 
@@ -3164,15 +3136,16 @@ void YFrameWindow::updateTaskBar() {
             if (fTrayApp->getShown()) ///!!! optimize
                 fTrayApp->repaint();
         }
+#if 0
         /// !!! optimize
-
         TrayPane *tp = taskBar->trayPane();
-	int const nw(tp->getRequiredWidth());
+        int const nw(tp->getRequiredWidth());
 
         if ((dw = nw - tp->width()))
             taskBar->trayPane()->setGeometry(
                 YRect(tp->x() - dw, tp->y(), nw, tp->height()));
 
+#endif
         taskBar->trayPane()->relayout();
     }
 #endif
@@ -3201,16 +3174,16 @@ void YFrameWindow::updateTaskBar() {
         /// !!! optimize
 
 #ifdef CONFIG_TRAY
-	if (dw) taskBar->taskPane()->setSize
-	    (taskBar->taskPane()->width() - dw, taskBar->taskPane()->height());
+        if (dw) taskBar->taskPane()->setSize
+            (taskBar->taskPane()->width() - dw, taskBar->taskPane()->height());
 #endif
         taskBar->taskPane()->relayout();
     }
 
 #ifndef LITE
     if (dw && NULL == taskBar->taskPane() && NULL != taskBar->addressBar())
-	taskBar->addressBar()->setSize
-	    (taskBar->addressBar()->width() - dw,
+        taskBar->addressBar()->setSize
+            (taskBar->addressBar()->width() - dw,
              taskBar->addressBar()->height());
 #endif
 }
@@ -3277,13 +3250,8 @@ void YFrameWindow::setWmUrgency(bool wmUrgency) {
 }
 
 int YFrameWindow::getScreen() {
-    XSizeHints *sh = client()->sizeHints();
-    int nx(normalX);
-    int ny(normalY);
-    int nw(sh ? normalW * sh->width_inc + sh->base_width
-           : normalW);
-    int nh(sh ? normalH * sh->height_inc + sh->base_height
-           : normalH);
+    int nx, ny, nw, nh;
+    getNormalGeometryInner(&nx, &ny, &nw, &nh);
     return manager->getScreenForRect(nx, ny, nw, nh);
 }
 
@@ -3320,7 +3288,7 @@ void YFrameWindow::wmArrange(int tcb, int lcr) {
 
     MSG(("wmArrange: setPosition(x = %d, y = %d)", newX, newY));
 
-    setPosition(newX, newY);
+    setCurrentPositionOuter(newX, newY);
 }
 
 void YFrameWindow::wmSnapMove(int tcb, int lcr) {
@@ -3374,7 +3342,7 @@ void YFrameWindow::wmSnapMove(int tcb, int lcr) {
 
     MSG(("NewPosition: x = %d, y = %d", newX, newY));
 
-    setPosition(newX, newY);
+    setCurrentPositionOuter(newX, newY);
 
     delete [] w;
 }
