@@ -90,8 +90,8 @@ void MiniIcon::paint(Graphics &g, const YRect &/*r*/) {
             int ty = (height() - 1 + font->height()) / 2 - font->descent();
             if (ty < 2) ty = 2;
 
-	    g.drawStringEllipsis(tx + 4 + YIcon::smallSize() + 2, ty,
-				 str, w - 4 - YIcon::smallSize() - 4);
+            g.drawStringEllipsis(tx + 4 + YIcon::smallSize() + 2, ty,
+                                 str, w - 4 - YIcon::smallSize() - 4);
         }
     }
 }
@@ -162,7 +162,7 @@ void MiniIcon::handleDrag(const XButtonEvent &down, const XMotionEvent &motion)
         if (x < mx) x = mx;
         if (y < my) y = my;
 
-        getFrame()->setPosition(x, y);
+        getFrame()->setCurrentGeometryOuter(YRect(x, y, width(), height()));
     }
 }
 #endif
