@@ -26,7 +26,8 @@ class ActivateWindowMenuItem: public YMenuItem, public YAction {
 public:
     ActivateWindowMenuItem(YFrameWindow *frame): 
         YMenuItem(frame->getTitle(), -1, 0, this, 0),
-	fFrame(frame) {
+        fFrame(frame)
+    {
 #ifndef LITE
         if (fFrame->clientIcon())
             setIcon(fFrame->clientIcon());
@@ -91,7 +92,7 @@ YMenu *YWindowManager::createWindowMenu(YMenu *menu, long workspace) {
                     continue;
 
                 if ((levelCount == 0 && level > 0) || 
-		    (layerCount == 0 && layer > 0) && needSeparator)
+                    (layerCount == 0 && layer > 0) && needSeparator)
                     menu->addSeparator();
 
                 menu->add(new ActivateWindowMenuItem(frame));
