@@ -14,7 +14,7 @@ char * findPath(const char *path, int mode, const char *name, bool /*path_relati
     char name_exe[1024];
 
     if (mode & X_OK)
-	name = strcat(strcpy(name_exe, name), ".exe");
+        name = strcat(strcpy(name_exe, name), ".exe");
 #endif
 
     if (*name == '/') { // check for root in XFreeOS/2
@@ -38,7 +38,7 @@ char * findPath(const char *path, int mode, const char *name, bool /*path_relati
             while (*p && *p != PATHSEP) p++;
 
             unsigned len(p - q);
-	    if (*p) ++p;
+            if (*p) ++p;
 
             if (len > 0 && len < sizeof(prog) - nameLen - 2) {
                 strncpy(prog, q, len);
@@ -64,7 +64,7 @@ char * findPath(const char *path, int mode, const char *name, bool /*path_relati
 
 #if !defined(NO_CONFIGURE) || !defined(NO_CONFIGURE_MENUS)
 
-static bool appendStr(char **dest, int &bufLen, int &len, char c) {	
+static bool appendStr(char **dest, int &bufLen, int &len, char c) {     
     if (*dest && len + 1 < bufLen) {
         (*dest)[len++] = c;
         (*dest)[len] = 0;
@@ -125,6 +125,13 @@ char *getArgument(char **dest, char *p, bool comma) {
                dq_open = !dq_open;
            else if (c == '\'')
                sq_open = !sq_open;
+           else if (c == '\\' && *p != '\n' && *p != '\r') {
+              // add any char protected by backslash and move forward
+              // exception: line ending (unwanted, may do bad things). OTOH, if
+              // the two last checks are disable, it will cause a side effect
+              // (multiline argument parsing with \n after \).
+               appendStr(dest, bufLen, len, *p++);
+           }
            else
                appendStr(dest, bufLen, len, c);
        }
@@ -293,7 +300,7 @@ char *parseOption(cfoption *options, char *str) {
 
     do {
         p = getArgument(&argument, p, true);
-	if (p == 0)
+        if (p == 0)
             break;
 
         p = setOption(options, name, argument, append, p);
