@@ -6,36 +6,37 @@
 class YCursor {
 public:
     YCursor(char const * filename):
-	fOwned(true) {
-	load(filename);
+        fOwned(true)
+    {
+        load(filename);
     }
 
     ~YCursor();
 
     YCursor(Cursor const cursor = None):
-	fCursor(cursor), fOwned(false) {
+        fCursor(cursor), fOwned(false) {
     }
 
-    YCursor(YCursor & other):
-	fCursor(other.fCursor), fOwned(true) {
-	other.fOwned = false;
+    YCursor(YCursor & other): fCursor(other.fCursor), fOwned(true)
+    {
+        other.fOwned = false;
     }
 
-    YCursor(YCursor const & other):
-	fCursor(other.fCursor), fOwned(false) {
+    YCursor(YCursor const & other): fCursor(other.fCursor), fOwned(false)
+    {
     }
 
     YCursor& operator= (YCursor & other) {
-	fCursor = other.fCursor;
-	fOwned = true;
-	other.fOwned = false;
-	return *this;
+        fCursor = other.fCursor;
+        fOwned = true;
+        other.fOwned = false;
+        return *this;
     }
 
     YCursor& operator= (YCursor const & other) {
-	fCursor = other.fCursor;
-	fOwned = false;
-	return *this;
+        fCursor = other.fCursor;
+        fOwned = false;
+        return *this;
     }
 
     void load(char const * path);
